void _call_gctpc(double in_x,double in_y,long in_sys,long in_zone,double in_parm_0,double in_parm_1,double in_parm_2,double in_parm_3,double in_parm_4,double in_parm_5,double in_parm_6,double in_parm_7,double in_parm_8,double in_parm_9,double in_parm_10,double in_parm_11,double in_parm_12,double in_parm_13,double in_parm_14,long in_unit,long in_datum,double *out_x,double *out_y,long out_sys,long out_zone,double out_parm_0,double out_parm_1,double out_parm_2,double out_parm_3,double out_parm_4,double out_parm_5,double out_parm_6,double out_parm_7,double out_parm_8,double out_parm_9,double out_parm_10,double out_parm_11,double out_parm_12,double out_parm_13,double out_parm_14,long out_unit,long out_datum,long *eflag);
